@@ -55,7 +55,7 @@ def loss_fn(model: LM, batch: jnp.ndarray):
     inputs = batch[:, :-1]
     targets = batch[:, 1:]
 
-    model, logits = pax.module_and_value(model)(inputs)
+    model, logits = pax.purecall(model, inputs)
     log_pr = jax.nn.log_softmax(logits, axis=-1)
     targets = jax.nn.one_hot(targets, num_classes=model.vocab_size)
     loss = -jnp.mean(jnp.sum(targets * log_pr, axis=-1))
@@ -67,7 +67,7 @@ def update_step(model_and_optim: Tuple[LM, GradientTransformation], batch: jnp.n
     (loss, model), grads = pax.value_and_grad(loss_fn, has_aux=True)(model, batch)
     grads = jax.lax.pmean(grads, axis_name="i")
     params = model.parameters()
-    optimizer, updates = pax.module_and_value(optimizer)(grads, params)
+    optimizer, updates = pax.purecall(optimizer, grads, params)
     params = params.map(jax.lax.sub, updates)
     model = model.update_parameters(params)
     return (model, optimizer), loss
